@@ -1,21 +1,26 @@
 import pytest
-from doltpy.core.dolt import Dolt, _execute, DoltException
+from doltpy.core.dolt import Dolt, _execute, DoltException, DoltDirectoryException
 from doltpy.core.write import UPDATE, import_df
 from doltpy.core.read import pandas_read_sql, read_table
 import shutil
 import pandas as pd
 import uuid
 import os
-from typing import Tuple
+from typing import Tuple, List
 from doltpy.core.tests.helpers import get_repo_path_tmp_path
 import sqlalchemy
 from retry import retry
 
+BASE_TEST_ROWS = [
+    {'name': 'Rafael',  'id': 1},
+    {'name': 'Novak', 'id': 2}
+]
+
 
 @pytest.fixture
 def create_test_data(tmp_path) -> str:
     path = os.path.join(tmp_path, str(uuid.uuid4()))
-    pd.DataFrame({'name': ['Rafael', 'Novak'], 'id': [1, 2]}).to_csv(path, index_label=False)
+    pd.DataFrame(BASE_TEST_ROWS).to_csv(path, index_label=False)
     yield path
     os.remove(path)
 
@@ -45,6 +50,12 @@ def test_init(tmp_path):
     shutil.rmtree(repo_data_dir)
 
 
+def test_bad_repo_path(tmp_path):
+    bad_repo_path = tmp_path
+    with pytest.raises(AssertionError):
+        Dolt(bad_repo_path)
+
+
 def test_commit(create_test_table):
     repo, test_table = create_test_table
     repo.add(test_table)
@@ -53,6 +64,22 @@ def test_commit(create_test_table):
     assert repo.status().is_clean and len(repo.log()) == before_commit_count + 1
 
 
+def test_dolt_log(create_test_table):
+    repo, test_table = create_test_table
+    message_one = 'Julianna, the very serious intellectual'
+    message_two = 'Added Stan the Man'
+    repo.add(test_table)
+    repo.commit('Julianna, the very serious intellectual')
+    repo.sql('INSERT INTO `test_players` (`name`, `id`) VALUES ("Stan", 4)')
+    repo.add(test_table)
+    repo.commit(message_two)
+    commits = list(repo.log().values())
+    current_commit = commits[0]
+    previous_commit = commits[1]
+    assert current_commit.message == message_two
+    assert previous_commit.message == message_one
+
+
 def test_get_dirty_tables(create_test_table):
     repo, test_table = create_test_table
     message = 'Committing test data'
@@ -127,7 +154,11 @@ def test_sql_server_unique(create_test_table, run_serve_mode, init_other_empty_t
     is running, not another repos MySQL server instance.
     :return:
     """
-    @retry(exceptions=(sqlalchemy.exc.OperationalError, sqlalchemy.exc.DatabaseError), delay=2, tries=10)
+    @retry(delay=2, tries=10, exceptions=(
+        sqlalchemy.exc.OperationalError,
+        sqlalchemy.exc.DatabaseError,
+        sqlalchemy.exc.InterfaceError,
+    ))
     def get_databases(dolt_repo: Dolt):
         with dolt_repo.engine.connect() as conn:
             result = conn.execute('SHOW DATABASES')
@@ -190,6 +221,37 @@ def test_sql(create_test_table):
     assert 'Roger' in test_data['name'].to_list()
 
 
+def test_sql_json(create_test_table):
+    repo, test_table = create_test_table
+    result = repo.sql(query='SELECT * FROM `{table}`'.format(table=test_table), result_format='json')['rows']
+    _verify_against_base_rows(result)
+
+
+def test_sql_csv(create_test_table):
+    repo, test_table = create_test_table
+    result = repo.sql(query='SELECT * FROM `{table}`'.format(table=test_table), result_format='csv')
+    _verify_against_base_rows(result)
+
+
+def test_sql_tabular(create_test_table):
+    repo, test_table = create_test_table
+    result = repo.sql(query='SELECT * FROM `{table}`'.format(table=test_table), result_format='tabular')
+    _verify_against_base_rows(result)
+
+
+def _verify_against_base_rows(result: List[dict]):
+    assert len(result) == len(BASE_TEST_ROWS)
+
+    result_sorted = sorted(result, key=lambda el: el['id'])
+    for left, right in zip(BASE_TEST_ROWS, result_sorted):
+        assert set(left.keys()) == set(right.keys())
+        for k in left.keys():
+            # Unfortunately csv.DictReader is a stream reader and thus does not look at all values for a given column
+            # and make type inference, so we have to cast everything to a string. JSON roundtrips, but would not
+            # preserve datetime objects for example.
+            assert str(left[k]) == str(right[k])
+
+
 TEST_IMPORT_FILE_DATA = '''
 name,id
 roger,1
