@@ -1,7 +1,9 @@
+import pytest
 from doltpy.etl.sql_sync.tests.helpers.tools import validate_get_target_writer, validate_drop_primary_keys
 from doltpy.etl.sql_sync.postgres import get_target_writer
 
 
+@pytest.mark.skip(reason="sql sync tests are currently unstable")
 def test_write_to_table(postgres_with_table):
     """
     See validate_write_to_table docstring.
@@ -12,6 +14,7 @@ def test_write_to_table(postgres_with_table):
     validate_get_target_writer(engine, table, get_target_writer)
 
 
+@pytest.mark.skip(reason="sql sync tests are currently unstable")
 def test_drop_primary_keys(postgres_with_table):
     """
     See validate_drop_primary_keys docstring.
